@@ -70,7 +70,7 @@ import static org.jruby.runtime.Visibility.PRIVATE;
 public class RubyStringScanner extends RubyObject {
     private static final long serialVersionUID = -3722138049229128675L;
 
-    private static final String STRSCAN_VERSION = "3.1.5";
+    private static final String STRSCAN_VERSION = "3.1.6";
 
     private RubyString str;
     private int curr = 0;
@@ -83,21 +83,24 @@ public class RubyStringScanner extends RubyObject {
 
     public static RubyClass createScannerClass(final Ruby runtime) {
         RubyClass Object = runtime.getObject();
+        ThreadContext context = runtime.getCurrentContext();
 
         RubyClass scannerClass = runtime.defineClass("StringScanner", Object, RubyStringScanner::new);
 
         RubyClass standardError = runtime.getStandardError();
-        RubyClass error = scannerClass.defineClassUnder("Error", standardError, standardError.getAllocator());
-        if (!Object.isConstantDefined("ScanError")) {
-            Object.defineConstant("ScanError", error);
+        RubyClass error = scannerClass.defineClassUnder(context, "Error", standardError, standardError.getAllocator());
+        if (!Object.isConstantDefined(context, "ScanError")) {
+            Object.defineConstant(context, "ScanError", error);
+            Object.deprecateConstant(context, "ScanError");
         }
 
         RubyString version = runtime.newString(STRSCAN_VERSION);
         version.setFrozen(true);
-        scannerClass.setConstant("Version", version);
+        scannerClass.setConstant(context, "Version", version);
         RubyString id = runtime.newString("$Id$");
         id.setFrozen(true);
-        scannerClass.setConstant("Id", id);
+        scannerClass.setConstant(context, "Id", id);
+        scannerClass.deprecateConstant(context, "Id");
 
         scannerClass.defineAnnotatedMethods(RubyStringScanner.class);
 
@@ -188,16 +191,6 @@ public class RubyStringScanner extends RubyObject {
         return this;
     }
 
-    @JRubyMethod(name = "clear")
-    public IRubyObject clear(ThreadContext context) {
-        check(context);
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#clear is obsolete; use #terminate instead");
-        }
-        return terminate(context);
-    }
-
     @JRubyMethod(name = "string")
     public RubyString string() {
         return str;
@@ -504,15 +497,6 @@ public class RubyStringScanner extends RubyObject {
                 adjustRegisterPosition(regs.getEnd(0)));
     }
 
-    @JRubyMethod(name = "getbyte")
-    public IRubyObject getbyte(ThreadContext context) {
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#getbyte is obsolete; use #get_byte instead");
-        }
-        return get_byte(context);
-    }
-
     @JRubyMethod(name = "scan_byte")
     public IRubyObject scan_byte(ThreadContext context) {
         Ruby runtime = context.runtime;
@@ -558,15 +542,6 @@ public class RubyStringScanner extends RubyObject {
         return extractBegLen(context.runtime, curr, len);
     }
 
-    @JRubyMethod(name = "peep")
-    public IRubyObject peep(ThreadContext context, IRubyObject length) {
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#peep is obsolete; use #peek instead");
-        }
-        return peek(context, length);
-    }
-
     @JRubyMethod(name = "scan_base10_integer", visibility = PRIVATE)
     public IRubyObject scan_base10_integer(ThreadContext context) {
         final Ruby runtime = context.runtime;
@@ -697,15 +672,6 @@ public class RubyStringScanner extends RubyObject {
         return curr >= str.getByteList().getRealSize() ? context.tru : context.fals;
     }
 
-    @JRubyMethod(name = "empty?")
-    public RubyBoolean empty_p(ThreadContext context) {
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#empty? is obsolete; use #eos? instead");
-        }
-        return eos_p(context);
-    }
-
     @JRubyMethod(name = "rest?")
     public RubyBoolean rest_p(ThreadContext context) {
         check(context);
@@ -734,15 +700,6 @@ public class RubyStringScanner extends RubyObject {
         return RubyFixnum.newFixnum(context.runtime, regs.getEnd(0) - regs.getBeg(0));
     }
 
-    @JRubyMethod(name = "matchedsize")
-    public IRubyObject matchedsize(ThreadContext context) {
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#matchedsize is obsolete; use #matched_size instead");
-        }
-        return matched_size(context);
-    }
-
     @JRubyMethod(name = "[]")
     public IRubyObject op_aref(ThreadContext context, IRubyObject idx) {
         check(context);
@@ -827,15 +784,6 @@ public class RubyStringScanner extends RubyObject {
         return RubyFixnum.newFixnum(runtime, realSize - curr);
     }
 
-    @JRubyMethod(name = "restsize")
-    public RubyFixnum restsize(ThreadContext context) {
-        Ruby runtime = context.runtime;
-        if (runtime.isVerbose()) {
-            runtime.getWarnings().warning(ID.DEPRECATED_METHOD, "StringScanner#restsize is obsolete; use #rest_size instead");
-        }
-        return rest_size(context);
-    }
-
     @JRubyMethod(name = "inspect")
     @Override
     public IRubyObject inspect() {
